==> haskell-conduit-extra-1.3.4-34-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-conduit-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: conduit-extra
version: 1.3.4
id: conduit-extra-1.3.4-ATsNYagzDpLJU3emZar2oE
key: conduit-extra-1.3.4-ATsNYagzDpLJU3emZar2oE
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: http://github.com/snoyberg/conduit
synopsis: Batteries included conduit: adapters for common libraries.
description:
    The conduit package itself maintains relative small dependencies. The purpose of this package is to collect commonly used utility functions wrapping other library dependencies, without depending on heavier-weight dependencies. The basic idea is that this package should only depend on haskell-platform packages and conduit.
category: Data, Conduit
abi: 1391c5c06de4830f908b767cd9cc0979
exposed: True
exposed-modules:
    Data.Conduit.Attoparsec Data.Conduit.Binary
    Data.Conduit.ByteString.Builder Data.Conduit.Filesystem
    Data.Conduit.Foldl Data.Conduit.Lazy Data.Conduit.Network
    Data.Conduit.Network.UDP Data.Conduit.Network.Unix
    Data.Conduit.Process Data.Conduit.Process.Typed Data.Conduit.Text
    Data.Conduit.Zlib
import-dirs: /usr/lib/ghc-8.6.5/site-local/conduit-extra-1.3.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/conduit-extra-1.3.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/conduit-extra-1.3.4
hs-libraries: HSconduit-extra-1.3.4-ATsNYagzDpLJU3emZar2oE
depends:
    async-2.2.2-5KbUJa8fnnu9oaTmXcEjsG
    attoparsec-0.13.2.3-7UnHU6FSzLmH0LcGk1o3QY base-4.12.0.0
    bytestring-0.10.8.2 conduit-1.3.1.2-7rOYGm9WTuB5ZvFVlqUZXq
    directory-1.3.3.0 filepath-1.4.2.1
    network-2.8.0.1-LEe4bVWblKP2CQkeLi73Oe
    primitive-0.6.4.0-ILgywxtLpvnAOlEISPpP5b process-1.6.5.0
    resourcet-1.2.2-38lkFSZ2J62BaKRW3aVOog stm-2.5.0.0
    streaming-commons-0.2.1.1-3FU3acGHUP158ft1TPilsC text-1.2.3.1
    transformers-0.5.6.2 typed-process-0.2.6.0-GXKfzgphJvrKEC1YYUwzMj
    unliftio-core-0.1.2.0-DmlZdkLzX278vkyONsp8WQ
haddock-interfaces: /usr/share/doc/haskell-conduit-extra/html/conduit-extra.haddock
haddock-html: /usr/share/doc/haskell-conduit-extra/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-conduit-extra-1.3.4-35-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-conduit-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: conduit-extra
version: 1.3.4
id: conduit-extra-1.3.4-1R3lGozgiKUCnPvEM5isAL
key: conduit-extra-1.3.4-1R3lGozgiKUCnPvEM5isAL
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: http://github.com/snoyberg/conduit
synopsis: Batteries included conduit: adapters for common libraries.
description:
    The conduit package itself maintains relative small dependencies. The purpose of this package is to collect commonly used utility functions wrapping other library dependencies, without depending on heavier-weight dependencies. The basic idea is that this package should only depend on haskell-platform packages and conduit.
category: Data, Conduit
abi: 2a69ab9f7ae25b7310220cf62331a663
exposed: True
exposed-modules:
    Data.Conduit.Attoparsec Data.Conduit.Binary
    Data.Conduit.ByteString.Builder Data.Conduit.Filesystem
    Data.Conduit.Foldl Data.Conduit.Lazy Data.Conduit.Network
    Data.Conduit.Network.UDP Data.Conduit.Network.Unix
    Data.Conduit.Process Data.Conduit.Process.Typed Data.Conduit.Text
    Data.Conduit.Zlib
import-dirs: /usr/lib/ghc-8.6.5/site-local/conduit-extra-1.3.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/conduit-extra-1.3.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/conduit-extra-1.3.4
hs-libraries: HSconduit-extra-1.3.4-1R3lGozgiKUCnPvEM5isAL
depends:
    async-2.2.2-5KbUJa8fnnu9oaTmXcEjsG
    attoparsec-0.13.2.3-7UnHU6FSzLmH0LcGk1o3QY base-4.12.0.0
    bytestring-0.10.8.2 conduit-1.3.1.2-7rOYGm9WTuB5ZvFVlqUZXq
    directory-1.3.3.0 filepath-1.4.2.1
    network-2.8.0.1-LEe4bVWblKP2CQkeLi73Oe
    primitive-0.6.4.0-ILgywxtLpvnAOlEISPpP5b process-1.6.5.0
    resourcet-1.2.2-38lkFSZ2J62BaKRW3aVOog stm-2.5.0.0
    streaming-commons-0.2.1.2-1lJcp2RmpUrDohwdNg16LC text-1.2.3.1
    transformers-0.5.6.2 typed-process-0.2.6.0-GXKfzgphJvrKEC1YYUwzMj
    unliftio-core-0.1.2.0-DmlZdkLzX278vkyONsp8WQ
haddock-interfaces: /usr/share/doc/haskell-conduit-extra/html/conduit-extra.haddock
haddock-html: /usr/share/doc/haskell-conduit-extra/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
